==> sms_message-1.0.1.tar.gz: sms_message/sms-android/app/src/main/java/com/sms/sendmessage/DBHandler.java <==
package com.sms.sendmessage;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import java.util.ArrayList;
import java.util.List;

public class DBHandler extends SQLiteOpenHelper {

    // creating a constant variables for our database.
    // below variable is for our database name.
    private static final String DB_NAME = "coursedb";

    // below int is our database version
    private static final int DB_VERSION = 1;

    // below variable is for our table name.
    private static final String TABLE_NAME = "mycourses";

    // below variable is for our id column.
    private static final String ID_COL = "id";

    // below variable is for our course name column
    private static final String UUID_COL = "uuid";

    // below variable id for our course duration column.
    private static final String MESS_COL = "mess";

    // below variable for our course description column.
    private static final String PHONE_COL = "phone";


    // creating a constructor for our database handler.
    public DBHandler(Context context) {
        super(context, DB_NAME, null, DB_VERSION);
    }

    // below method is for creating a database by running a sqlite query
    @Override
    public void onCreate(SQLiteDatabase db) {
        // on below line we are creating
        // an sqlite query and we are
        // setting our column names
        // along with their data types.
        String query = "CREATE TABLE " + TABLE_NAME + " ("
                + ID_COL + " INTEGER PRIMARY KEY AUTOINCREMENT, "
                + UUID_COL + " TEXT,"
                + MESS_COL + " TEXT,"
                + PHONE_COL + " TEXT)";

        // at last we are calling a exec sql
        // method to execute above sql query
        db.execSQL(query);
    }

    // this method is use to add new course to our sqlite database.
    public void addNewCourse(String uuid, String mess, String phone) {

        // on below line we are creating a variable for
        // our sqlite database and calling writable method
        // as we are writing data in our database.
        SQLiteDatabase db = this.getWritableDatabase();

        // on below line we are creating a
        // variable for content values.
        ContentValues values = new ContentValues();

        // on below line we are passing all values
        // along with its key and value pair.
        values.put(UUID_COL, uuid);
        values.put(MESS_COL, mess);
        values.put(PHONE_COL, phone);

        // after adding all values we are passing
        // content values to our table.
        db.insert(TABLE_NAME, null, values);

        // at last we are closing our
        // database after adding database.
        db.close();
    }

    public void resetDB() {
        SQLiteDatabase db = this.getWritableDatabase();

        db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME);

        String query = "CREATE TABLE " + TABLE_NAME + " ("
                + ID_COL + " INTEGER PRIMARY KEY AUTOINCREMENT, "
                + UUID_COL + " TEXT,"
                + MESS_COL + " TEXT,"
                + PHONE_COL + " TEXT)";

        // at last we are calling a exec sql
        // method to execute above sql query
        db.execSQL(query);
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        // this method is called to check if the table exists already.
        db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME);
        onCreate(db);
    }

    //Lấy toàn bộ SP
    public ArrayList<Data> getAllProducts() {

        ArrayList<Data> datas = new ArrayList<>();

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT " + UUID_COL + ", " + MESS_COL + ", " + PHONE_COL + " from " + TABLE_NAME, null);

        //Đến dòng đầu của tập dữ liệu
        cursor.moveToFirst();
        while (!cursor.isAfterLast()) {
            String uuid = cursor.getString(0);
            String mess = cursor.getString(1);
            String phone = cursor.getString(2);

            datas.add(new Data(uuid, mess, phone));
            cursor.moveToNext();
        }

        cursor.close();

        return datas;
    }
}

==> sms_message-1.0.7.tar.gz: sms_message/sms-android/app/src/main/java/com/sms/sendmessage/DBHandler.java <==
package com.sms.sendmessage;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import java.util.ArrayList;

public class DBHandler extends SQLiteOpenHelper {

    // creating a constant variables for our database.
    // below variable is for our database name.
    private static final String DB_NAME = "smsdb";

    // below int is our database version
    private static final int DB_VERSION = 1;

    // below variable is for our table name.
    private static final String TABLE_NAME = "mysms";

    // below variable is for our id column.
    private static final String ID_COL = "id";

    // below variable is for our course name column
    private static final String UUID_COL = "uuid";

    // below variable id for our course duration column.
    private static final String MESS_COL = "mess";

    // below variable for our course description column.
    private static final String PHONE_COL = "phone";

    // Singleton db handler.
    private static DBHandler instance;

    public static synchronized DBHandler getInstance(Context context) {
        if (instance == null) {
          instance = new DBHandler(context.getApplicationContext());
        }
         return instance;
    }

    // creating a constructor for our database handler.
    public DBHandler(Context context) {
        super(context, DB_NAME, null, DB_VERSION);
    }

    // below method is for creating a database by running a sqlite query
    @Override
    public void onCreate(SQLiteDatabase db) {
        // on below line we are creating
        // an sqlite query and we are
        // setting our column names
        // along with their data types.
        String query = "CREATE TABLE " + TABLE_NAME + " ("
                + ID_COL + " INTEGER PRIMARY KEY AUTOINCREMENT, "
                + UUID_COL + " TEXT,"
                + MESS_COL + " TEXT,"
                + PHONE_COL + " TEXT)";

        // at last we are calling a exec sql
        // method to execute above sql query
        db.execSQL(query);
    }

    // this method is use to add new course to our sqlite database.
    public void addNewCourse(String uuid, String mess, String phone) {

        // on below line we are creating a variable for
        // our sqlite database and calling writable method
        // as we are writing data in our database.
        SQLiteDatabase db = this.getWritableDatabase();

        // on below line we are creating a
        // variable for content values.
        ContentValues values = new ContentValues();

        // on below line we are passing all values
        // along with its key and value pair.
        values.put(UUID_COL, uuid);
        values.put(MESS_COL, mess);
        values.put(PHONE_COL, phone);

        // after adding all values we are passing
        // content values to our table.
        db.insert(TABLE_NAME, null, values);

        // at last we are closing our
        // database after adding database.
        db.close();
    }

    public void resetDB() {
        SQLiteDatabase db = this.getWritableDatabase();

        db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME);

        String query = "CREATE TABLE " + TABLE_NAME + " ("
                + ID_COL + " INTEGER PRIMARY KEY AUTOINCREMENT, "
                + UUID_COL + " TEXT,"
                + MESS_COL + " TEXT,"
                + PHONE_COL + " TEXT)";

        // at last we are calling a exec sql
        // method to execute above sql query
        db.execSQL(query);
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        // this method is called to check if the table exists already.
        db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME);
        onCreate(db);
    }

    //Get all of SP
    public ArrayList<Data> getAllProducts() {

        ArrayList<Data> datas = new ArrayList<>();

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT " + UUID_COL + ", " + MESS_COL + ", " + PHONE_COL + " from " + TABLE_NAME, null);

        //Move to first data array
        cursor.moveToFirst();
        while (!cursor.isAfterLast()) {
            String uuid = cursor.getString(0);
            String mess = cursor.getString(1);
            String phone = cursor.getString(2);

            datas.add(new Data(mess, phone, uuid));
            cursor.moveToNext();
        }

        cursor.close();
        db = getWritableDatabase();
        db.execSQL("DELETE FROM " + TABLE_NAME);
        return datas;
    }

    // Method to check if a UUID exists in the database
    public boolean isUUIDExist(String uuid) {
        SQLiteDatabase db = this.getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT 1 FROM " + TABLE_NAME + " WHERE " + UUID_COL + " = ?", new String[]{uuid});
        boolean exists = cursor.getCount() > 0;
        cursor.close();
        return exists;
    }

}
